@@ -140,7 +140,7 @@ class Recorder:
         try:
             from IPython.display import Code
         except ImportError as exc:
-            raise NotImplementedError() from exc
+            raise NotImplementedError from exc
         lines = self._get_repr_lines()
         code = Code("\n".join(lines), language="C")
         head, tail = self._repr_base_()
