@@ -42,9 +42,9 @@ class DataType:
         try:
             t1 = self.np_type
             t2 = lookup_dtype(other).np_type
-            return (t1.kind, t1.itemsize, t1.name) < (t2.kind, t2.itemsize, t2.name)
         except ValueError:
             raise TypeError(f"Invalid or unknown datatype: {other}") from None
+        return (t1.kind, t1.itemsize, t1.name) < (t2.kind, t2.itemsize, t2.name)
 
     def __reduce__(self):
         if self._is_udt:
@@ -129,7 +129,8 @@ def register_anonymous(dtype, name=None):
                 np_repr = np_repr[: _lib.GxB_MAX_NAME_LEN]
             _warnings.warn(
                 f"{msg}.  It will use the following name, "
-                f"and the dtype may need to be specified when deserializing: {np_repr}"
+                f"and the dtype may need to be specified when deserializing: {np_repr}",
+                stacklevel=2,
             )
         status = _lib.GxB_Type_new(gb_obj, dtype.itemsize, np_repr, _NULL)
     else:
@@ -174,7 +175,7 @@ if _supports_complex and hasattr(_lib, "GxB_FC32"):
     FC32 = DataType(
         "FC32", _lib.GxB_FC32, "GxB_FC32", "float _Complex", _numba.types.complex64, _np.complex64
     )
-if _supports_complex and hasattr(_lib, "GrB_FC32"):  # pragma: no coverage (invalid)
+if _supports_complex and hasattr(_lib, "GrB_FC32"):  # pragma: no cover (unused)
     FC32 = DataType(
         "FC32", _lib.GrB_FC32, "GrB_FC32", "float _Complex", _numba.types.complex64, _np.complex64
     )
@@ -187,7 +188,7 @@ if _supports_complex and hasattr(_lib, "GxB_FC64"):
         _numba.types.complex128,
         _np.complex128,
     )
-if _supports_complex and hasattr(_lib, "GrB_FC64"):  # pragma: no coverage (invalid)
+if _supports_complex and hasattr(_lib, "GrB_FC64"):  # pragma: no cover (unused)
     FC64 = DataType(
         "FC64",
         _lib.GrB_FC64,
@@ -291,7 +292,7 @@ def lookup_dtype(key, value=None):
 
 def unify(type1, type2, *, is_left_scalar=False, is_right_scalar=False):
     """
-    Returns a type that can hold both type1 and type2
+    Returns a type that can hold both type1 and type2.
 
     For example:
     unify(INT32, INT64) -> INT64
@@ -330,7 +331,7 @@ def _default_name(dtype):
         args = ", ".join(
             f"{name!r}: {_default_name(dtype.fields[name][0])}" for name in dtype.names
         )
-        return "{%s}" % args
+        return f"{{{args}}}"
     return repr(dtype)
 
 
@@ -357,14 +358,17 @@ def _dtype_to_string(dtype):
             return s
     except Exception:
         pass
-    if _np.dtype(np_type.str) == np_type:
-        return repr(np_type.str)
-    else:  # pragma: no cover (safety)
+    if _np.dtype(np_type.str) != np_type:  # pragma: no cover (safety)
         raise ValueError(f"Unable to reliably convert dtype to string and back: {dtype}")
+    return repr(np_type.str)
 
 
 def _string_to_dtype(s):
-    """_string_to_dtype(_dtype_to_string(dtype)) == dtype"""
+    """Convert a string back to a dtype.
+
+    >>> _string_to_dtype(_dtype_to_string(dtype)) == dtype
+    True
+    """
     try:
         return lookup_dtype(s)
     except Exception:
