@@ -4,6 +4,7 @@ import numpy as _np
 
 from . import backend as _backend
 from .core.matrix import Matrix as _Matrix
+from .core.utils import normalize_values as _normalize_values
 from .core.utils import output_type as _output_type
 from .core.vector import Vector as _Vector
 from .dtypes import lookup_dtype as _lookup_dtype
@@ -57,10 +58,14 @@ def from_networkx(G, nodelist=None, dtype=None, weight="weight", name=None):
     return from_scipy_sparse(A, name=name)
 
 
-# TODO: add parameter to indicate empty value (default is 0 and NaN)
-def from_numpy(m):
+def from_numpy(m):  # pragma: no cover (deprecated)
     """Create a sparse Vector or Matrix from a dense numpy array.
 
+    .. deprecated:: 2023.2.0
+        `from_numpy` will be removed in a future release.
+        Use `Vector.from_dense` or `Matrix.from_dense` instead.
+        Will be removed in version 2023.10.0 or later
+
     A value of 0 is considered as "missing".
 
     - m.ndim == 1 returns a `Vector`
@@ -74,10 +79,21 @@ def from_numpy(m):
     m : np.ndarray
         Input array
 
+    See Also
+    --------
+    Matrix.from_dense
+    Vector.from_dense
+    from_scipy_sparse
+
     Returns
     -------
     Vector or Matrix
     """
+    _warn(
+        "`graphblas.io.from_numpy` is deprecated; "
+        "use `Matrix.from_dense` and `Vector.from_dense` instead.",
+        DeprecationWarning,
+    )
     if m.ndim > 2:
         raise _GraphblasException("m.ndim must be <= 2")
 
@@ -95,20 +111,6 @@ def from_numpy(m):
     return from_scipy_sparse(A)
 
 
-def from_scipy_sparse_matrix(m, *, dup_op=None, name=None):
-    """dtype is inferred from m.dtype"""
-    _warn(
-        "`from_scipy_sparse_matrix` is deprecated; please use `from_scipy_sparse` instead.",
-        DeprecationWarning,
-    )
-    A = m.tocoo()
-    nrows, ncols = A.shape
-    dtype = _lookup_dtype(m.dtype)
-    return _Matrix.from_coo(
-        A.row, A.col, A.data, nrows=nrows, ncols=ncols, dtype=dtype, dup_op=dup_op, name=name
-    )
-
-
 def from_scipy_sparse(A, *, dup_op=None, name=None):
     """Create a Matrix from a scipy.sparse array or matrix.
 
@@ -220,9 +222,63 @@ def from_awkward(A, *, name=None):
     raise ValueError(f"Invalid format for Matrix: {format}")
 
 
+def from_pydata_sparse(s, *, dup_op=None, name=None):
+    """Create a Vector or a Matrix from a pydata.sparse array or matrix.
+
+    Input data in "gcxs" format will be efficient when importing with SuiteSparse:GraphBLAS.
+
+    Parameters
+    ----------
+    s : sparse
+        PyData sparse array or matrix (see https://sparse.pydata.org)
+    dup_op : BinaryOp, optional
+        Aggregation function for formats that allow duplicate entries (e.g. coo)
+    name : str, optional
+        Name of resulting Matrix
+
+    Returns
+    -------
+    :class:`~graphblas.Vector`
+    :class:`~graphblas.Matrix`
+    """
+    try:
+        import sparse
+    except ImportError:  # pragma: no cover (import)
+        raise ImportError("sparse is required to import from pydata sparse") from None
+    if not isinstance(s, sparse.SparseArray):
+        raise TypeError(
+            "from_pydata_sparse only accepts objects from the `sparse` library; "
+            "see https://sparse.pydata.org"
+        )
+    if s.ndim > 2:
+        raise _GraphblasException("m.ndim must be <= 2")
+
+    if s.ndim == 1:
+        # the .asformat('coo') makes it easier to convert dok/gcxs using a single approach
+        _s = s.asformat("coo")
+        return _Vector.from_coo(
+            _s.coords, _s.data, dtype=_s.dtype, size=_s.shape[0], dup_op=dup_op, name=name
+        )
+    # handle two-dimensional arrays
+    if isinstance(s, sparse.GCXS):
+        return from_scipy_sparse(s.to_scipy_sparse(), dup_op=dup_op, name=name)
+    if isinstance(s, (sparse.DOK, sparse.COO)):
+        _s = s.asformat("coo")
+        return _Matrix.from_coo(
+            *_s.coords,
+            _s.data,
+            nrows=_s.shape[0],
+            ncols=_s.shape[1],
+            dtype=_s.dtype,
+            dup_op=dup_op,
+            name=name,
+        )
+    raise ValueError(f"Unknown sparse array type: {type(s).__name__}")  # pragma: no cover (safety)
+
+
 # TODO: add parameters to allow different networkx classes and attribute names
 def to_networkx(m, edge_attribute="weight"):
-    """Create a networkx DiGraph from a square adjacency Matrix
+    """Create a networkx DiGraph from a square adjacency Matrix.
 
     Parameters
     ----------
@@ -249,9 +305,14 @@ def to_networkx(m, edge_attribute="weight"):
     return G
 
 
-def to_numpy(m):
+def to_numpy(m):  # pragma: no cover (deprecated)
     """Create a dense numpy array from a sparse Vector or Matrix.
 
+    .. deprecated:: 2023.2.0
+        `to_numpy` will be removed in a future release.
+        Use `Vector.to_dense` or `Matrix.to_dense` instead.
+        Will be removed in version 2023.10.0 or later
+
     Missing values will become 0 in the output.
 
     numpy dtype will match the GraphBLAS dtype
@@ -261,12 +322,23 @@ def to_numpy(m):
     m : Vector or Matrix
         GraphBLAS Vector or Matrix
 
+    See Also
+    --------
+    to_scipy_sparse
+    Matrix.to_dense
+    Vector.to_dense
+
     Returns
     -------
     np.ndarray
     """
+    _warn(
+        "`graphblas.io.to_numpy` is deprecated; "
+        "use `Matrix.to_dense` and `Vector.to_dense` instead.",
+        DeprecationWarning,
+    )
     try:
-        import scipy  # noqa
+        import scipy  # noqa: F401
     except ImportError:  # pragma: no cover (import)
         raise ImportError("scipy is required to export to numpy") from None
     if _output_type(m) is _Vector:
@@ -275,34 +347,8 @@ def to_numpy(m):
     return sparse.toarray()
 
 
-def to_scipy_sparse_matrix(m, format="csr"):  # pragma: no cover (deprecated)
-    """format: str in {'bsr', 'csr', 'csc', 'coo', 'lil', 'dia', 'dok'}"""
-    import scipy.sparse as ss
-
-    _warn(
-        "`to_scipy_sparse_matrix` is deprecated; please use `to_scipy_sparse` instead.",
-        DeprecationWarning,
-    )
-    format = format.lower()
-    if _output_type(m) is _Vector:
-        indices, data = m.to_coo()
-        if format == "csc":
-            return ss.csc_matrix((data, indices, [0, len(data)]), shape=(m._size, 1))
-        rv = ss.csr_matrix((data, indices, [0, len(data)]), shape=(1, m._size))
-        if format == "csr":
-            return rv
-    else:
-        rows, cols, data = m.to_coo()
-        rv = ss.coo_matrix((data, (rows, cols)), shape=m.shape)
-        if format == "coo":
-            return rv
-    if format not in {"bsr", "csr", "csc", "coo", "lil", "dia", "dok"}:
-        raise _GraphblasException(f"Invalid format: {format}")
-    return rv.asformat(format)
-
-
 def to_scipy_sparse(A, format="csr"):
-    """Create a scipy.sparse array from a GraphBLAS Matrix or Vector
+    """Create a scipy.sparse array from a GraphBLAS Matrix or Vector.
 
     Parameters
     ----------
@@ -337,13 +383,10 @@ def to_scipy_sparse(A, format="csr"):
                 info["col_indices"] = info["row_indices"]
         else:
             info = A.ss.export(format, sort=True)
-        if info["is_iso"]:
-            info["values"] = _np.broadcast_to(info["values"], A._nvals)
+        values = _normalize_values(A, info["values"], None, (A._nvals,), info["is_iso"])
         if format == "csr":
-            return ss.csr_array(
-                (info["values"], info["col_indices"], info["indptr"]), shape=A.shape
-            )
-        return ss.csc_array((info["values"], info["row_indices"], info["indptr"]), shape=A.shape)
+            return ss.csr_array((values, info["col_indices"], info["indptr"]), shape=A.shape)
+        return ss.csc_array((values, info["row_indices"], info["indptr"]), shape=A.shape)
     elif format == "csr":
         indptr, cols, vals = A.to_csr()
         return ss.csr_array((vals, cols, indptr), shape=A.shape)
@@ -362,7 +405,7 @@ _AwkwardDoublyCompressedMatrix = None
 
 
 def to_awkward(A, format=None):
-    """Create an Awkward Array from a GraphBLAS Matrix
+    """Create an Awkward Array from a GraphBLAS Matrix.
 
     Parameters
     ----------
@@ -382,10 +425,19 @@ def to_awkward(A, format=None):
     awkward.Array
 
     """
-    import awkward._v2 as ak
-    from awkward._v2.forms.listoffsetform import ListOffsetForm
-    from awkward._v2.forms.numpyform import NumpyForm
-    from awkward._v2.forms.recordform import RecordForm
+    try:
+        # awkward version 1
+        # MAINT: we can probably drop awkward v1 at the end of 2024 or 2025
+        import awkward._v2 as ak
+        from awkward._v2.forms.listoffsetform import ListOffsetForm
+        from awkward._v2.forms.numpyform import NumpyForm
+        from awkward._v2.forms.recordform import RecordForm
+    except ImportError:
+        # awkward version 2
+        import awkward as ak
+        from awkward.forms.listoffsetform import ListOffsetForm
+        from awkward.forms.numpyform import NumpyForm
+        from awkward.forms.recordform import RecordForm
 
     out_type = _output_type(A)
     if format is None:
@@ -442,7 +494,7 @@ def to_awkward(A, format=None):
         )
         if format.startswith("hyper"):
             global _AwkwardDoublyCompressedMatrix
-            if _AwkwardDoublyCompressedMatrix is None:
+            if _AwkwardDoublyCompressedMatrix is None:  # pylint: disable=used-before-assignment
                 # Define behaviors to make all fields function at the top-level
                 @ak.behaviors.mixins.mixin_class(ak.behavior)
                 class _AwkwardDoublyCompressedMatrix:
@@ -474,6 +526,46 @@ def to_awkward(A, format=None):
     return ret
 
 
+def to_pydata_sparse(A, format="coo"):
+    """Create a pydata.sparse array from a GraphBLAS Matrix or Vector.
+
+    Parameters
+    ----------
+    A : Matrix or Vector
+        GraphBLAS object to be converted
+    format : str
+        {'coo', 'dok', 'gcxs'}
+
+    Returns
+    -------
+    sparse array (see https://sparse.pydata.org)
+
+    """
+    try:
+        from sparse import COO
+    except ImportError:  # pragma: no cover (import)
+        raise ImportError("sparse is required to export to pydata sparse") from None
+
+    format = format.lower()
+    if format not in {"coo", "dok", "gcxs"}:
+        raise ValueError(f"Invalid format: {format}")
+
+    if _output_type(A) is _Vector:
+        indices, values = A.to_coo(sort=False)
+        s = COO(indices, values, shape=A.shape)
+    else:
+        if format == "gcxs":
+            B = to_scipy_sparse(A, format="csr")
+        else:
+            # obtain an intermediate conversion via hardcoded 'coo' intermediate object
+            B = to_scipy_sparse(A, format="coo")
+        # convert to pydata.sparse
+        s = COO.from_scipy_sparse(B)
+
+    # express in the desired format
+    return s.asformat(format)
+
+
 def mmread(source, *, dup_op=None, name=None):
     """Create a GraphBLAS Matrix from the contents of a Matrix Market file.
 
@@ -504,11 +596,7 @@ def mmread(source, *, dup_op=None, name=None):
         return _Matrix.from_coo(
             array.row, array.col, array.data, nrows=nrows, ncols=ncols, dup_op=dup_op, name=name
         )
-    if _backend == "suitesparse":
-        return _Matrix.ss.import_fullr(values=array, take_ownership=True, name=name)
-    rv = _Matrix(array.dtype, *array.shape, name=name)
-    rv[...] = array
-    return rv
+    return _Matrix.from_dense(array, name=name)
 
 
 def mmwrite(target, matrix, *, comment="", field=None, precision=None, symmetry=None):
