@@ -53,15 +53,10 @@ def draw(m):  # pragma: no cover
 
     .. image:: /_static/img/draw-example.png
     """
-    try:
-        nx, plt = _get_imports(["nx", "plt"], "draw")
-    except ImportError as exc:
-        print(exc.msg)
-        return
+    nx, plt = _get_imports(["nx", "plt"], "draw")
     typ = _output_type(m)
     if typ is not _Matrix and typ is not _TransposedMatrix:
-        print(f"Can only draw a Matrix, not {type(m)}")
-        return
+        raise TypeError(f"Can only draw a Matrix, not {type(m)}")
 
     g = to_networkx(m)
     pos = nx.spring_layout(g)
@@ -72,7 +67,7 @@ def draw(m):  # pragma: no cover
 
 
 def spy(M, *, centered=False, show=True, figure=None, axes=None, figsize=None, **kwargs):
-    """Plot the sparsity pattern of a Matrix using `matplotlib.spy`
+    """Plot the sparsity pattern of a Matrix using `matplotlib.spy`.
 
     See:
     - https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.spy.html
@@ -109,7 +104,7 @@ def spy(M, *, centered=False, show=True, figure=None, axes=None, figsize=None, *
 
 
 def datashade(M, agg="count", *, width=None, height=None, opts_kwargs=None, **kwargs):
-    """Interactive plot of the sparsity pattern of a Matrix using hvplot and datashader
+    """Interactive plot of the sparsity pattern of a Matrix using hvplot and datashader.
 
     The `datashader` library rasterizes large data into a 2d grid of pixels.  Each pixel
     may contain multiple data points, which are combined by an aggregator (`agg="count"`).
@@ -187,7 +182,7 @@ def datashade(M, agg="count", *, width=None, height=None, opts_kwargs=None, **kw
             images.extend(image_row)
         return hv.Layout(images).cols(ncols)
 
-    kwds = dict(  # noqa
+    kwds = dict(  # noqa: C408 pylint: disable=use-dict-literal
         x="col",
         y="row",
         c="val",
